@@ -51,6 +51,8 @@ class HistopathologicalCancerDetectionUseCase(BaseProcessor):
     def __init__(self):
         super().__init__("histopathological_cancer_detection")
         self.category = "healthcare"
+        self.CASE_TYPE = "histopathological_cancer_detection"
+        self.CASE_VERSION = "1.0"
         self.target_categories = ['Benign Cell', 'Cancer Cell', 'Correct Lumen', 'Incorrect Lumen']
         self.smoothing_tracker = None
         self.tracker = None
