@@ -413,6 +413,10 @@ class ColorDetectionUseCase(BaseProcessor):
             
             # Step 6: Update tracking state
             self._update_color_tracking_state(color_processed_data)
+            print("--------------------tracking state updated-------------------")
+            print(self._color_total_track_ids)
+            print(self._color_current_frame_track_ids)
+            print("--------------------tracking state updated-------------------")
             color_processed_data = self._attach_masks_to_detections(color_processed_data, raw_processed_data)
             self._total_frame_counter += 1
             
